<?php
namespace bwdhtsx_TimelineSlider_namespace;

use bwdhtsx_TimelineSlider_namespace\PageSettings\Page_Settings;
define( "BWDHTSX_ASFSK_ASSETS_PUBLIC_DIR_FILE", plugin_dir_url( __FILE__ ) . "assets/public" );
define( "BWDHTSX_ASFSK_ASSETS_ADMIN_DIR_FILE", plugin_dir_url( __FILE__ ) . "assets/admin" );
class Classbwdhtsx_TimelineSlider {

	private static $_instance = null;

	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

	public function bwdhtsx_admin_editor_scripts() {
		add_filter( 'script_loader_tag', [ $this, 'bwdhtsx_admin_editor_scripts_as_a_module' ], 10, 2 );
	}

	public function bwdhtsx_admin_editor_scripts_as_a_module( $tag, $handle ) {
		if ( 'bwdhtsx_TimelineSlider_editor' === $handle ) {
			$tag = str_replace( '<script', '<script type="module"', $tag );
		}

		return $tag;
	}

	private function include_widgets_files() {
		require_once( __DIR__ . '/widgets/bwdhtsx-timeline-slider-widgets.php' );
	}

	public function bwdhtsx_register_widgets() {
		// Its is now safe to include Widgets files
		$this->include_widgets_files();

		// Register WidgetsF
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\bwdhtsx_TimelineSlider_widgets());
	}

	private function add_page_settings_controls() {
		require_once( __DIR__ . '/page-settings/bwdhtsx-timeline-slider-manager.php' );
		new Page_Settings();
	}

	// Register Category
	function bwdhtsx_TimelineSlider_add_elementor_widget_categories( $elements_manager ) {

		$elements_manager->add_category(
			'bwdhtsx-TimelineSlider-category',
			[
				'title' => esc_html__( 'Horizontal Timeline Slider', 'bwdhtsx-slider-timeline' ),
				'icon' => 'eicon-person',
			]
		);
	}

	//css-js-link-here
	public function bwdhtsx_all_assets_for_the_public(){
		wp_enqueue_script( 'bwdhtsx-TimelineSlider-slick', plugin_dir_url( __FILE__ ) . 'assets/public/js/slick.min.js', array('jquery'), '1.3', true );
		wp_enqueue_script( 'bwdhtsx-TimelineSlider-main', plugin_dir_url( __FILE__ ) . 'assets/public/js/main.js', array('jquery'), '1.3', true );
		$all_css_file = array(
			'bwdhtsx-TimelineSlider-plugin-slick' => array('bwdhtsx-TimelineSlider_css_path_define'=>BWDHTSX_ASFSK_ASSETS_PUBLIC_DIR_FILE . '/css/slick.css'),
			'bwdhtsx-TimelineSlider-plugin-main' => array('bwdhtsx-TimelineSlider_css_path_define'=>BWDHTSX_ASFSK_ASSETS_PUBLIC_DIR_FILE . '/css/main.css'),
        );
        foreach($all_css_file as $handle => $fileinfo){
            wp_enqueue_style( $handle, $fileinfo['bwdhtsx-TimelineSlider_css_path_define'], null, '1.3', 'all');
        }

	}

	//admin-icon
	public function bwdhtsx_all_assets_for_elementor_editor_admin(){
		$all_css_js_file = array(
            'bwdhtsx-TimelineSlider-admin-main' => array('bwdhtsx_path_admin_define'=>BWDHTSX_ASFSK_ASSETS_ADMIN_DIR_FILE . '/css/icon.css'),
        );
        foreach($all_css_js_file as $handle => $fileinfo){
            wp_enqueue_style( $handle, $fileinfo['bwdhtsx_path_admin_define'], null, '1.3', 'all');
        }
	}

	public function __construct() {

		// For public assets
		add_action('wp_enqueue_scripts', [$this, 'bwdhtsx_all_assets_for_the_public']);

		// For Elementor Editor
		add_action('elementor/editor/before_enqueue_scripts', [$this, 'bwdhtsx_all_assets_for_elementor_editor_admin']);

		// Register Category
		add_action( 'elementor/elements/categories_registered', [ $this, 'bwdhtsx_TimelineSlider_add_elementor_widget_categories' ] );

		// Register widgets
		add_action( 'elementor/widgets/widgets_registered', [ $this, 'bwdhtsx_register_widgets' ] );

		// Register editor scripts
		add_action( 'elementor/editor/after_enqueue_scripts', [ $this, 'bwdhtsx_admin_editor_scripts' ] );

		$this->add_page_settings_controls();
	}
}

// Instantiate Plugin Class
Classbwdhtsx_TimelineSlider::instance();